pyuppsala documentation
=======================

**pyuppsala** is a Python binding for the `Uppsala <https://crates.io/crates/uppsala>`_
XML library -- a zero-dependency, pure-Rust implementation of XML 1.0, Namespaces,
XPath 1.0, and XSD validation.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   quickstart
   api
   exceptions
   examples
